@@ -4,24 +4,24 @@
 ## has similar calling sequence as integration routines from package deSolve
 ## =============================================================================
 
-steady  <- function (y, time=NULL, func, parms=NULL, method="stode", ...)  {
+steady  <- function (y, time=NULL, func, parms=NULL, method="stode", times = time, ...)  {
 
   if (!method %in% c("stode", "stodes","runsteady"))
     stop (" 'method' should be one of 'stode', 'stodes', 'runsteady'")   
 
-  if (is.null(time)) {
+  if (is.null(times)) {
     if (method %in% c("stode", "stodes")) 
-      time <- 0
+      times <- 0
     else
-      time <- c(0,Inf)  
+      times <- c(0,Inf)  
   }  
 
   if (method=="stode")
-    out <- stode(y,time,func,parms=parms,...)  else
+    out <- stode(y,times,func,parms=parms,...)  else
   if (method=="stodes")
-    out <- stodes(y,time,func,parms=parms,...) else
+    out <- stodes(y,times,func,parms=parms,...) else
   if (method=="runsteady")
-    out <- runsteady(y,times=time,func,parms=parms,...)
+    out <- runsteady(y,time=times,func,parms=parms,...)
   class(out) <- c("steady","rootSolve","list")    # a steady-state 
   attr(out, "nspec") <- length(y)
   attr(out,"ynames") <- names(y)
